.. image:: https://travis-ci.org/asphalt-framework/asphalt-serialization.svg?branch=master
  :target: https://travis-ci.org/asphalt-framework/asphalt-serialization
  :alt: Build Status
.. image:: https://coveralls.io/repos/asphalt-framework/asphalt-serialization/badge.svg?branch=master&service=github
  :target: https://coveralls.io/github/asphalt-framework/asphalt-serialization?branch=master
  :alt: Code Coverage
.. image:: https://codeclimate.com/github/asphalt-framework/asphalt-serialization/badges/gpa.svg
  :target: https://codeclimate.com/github/asphalt-framework/asphalt-serialization
  :alt: Code Climate

This component of the Asphalt framework provides integration with a number of different
serialization schemes with a common API.

Supported serializers:

* CBOR_
* JSON_
* msgpack_
* Pickle_
* YAML_

Additional backends may be provided through third party plugins.


Project links
-------------

* `Documentation`_
* `Help and support`_
* `Source code`_
* `Issue tracker`_


.. _CBOR: http://cbor.io/
.. _JSON: http://wikipedia.org/wiki/JSON
.. _msgpack: http://msgpack.org/
.. _Pickle: https://docs.python.org/3/library/pickle.html
.. _YAML: http://wikipedia.org/wiki/YAML
.. _Documentation: http://asphalt-serialization.readthedocs.org/
.. _Help and support: https://github.com/asphalt-framework/asphalt/wiki/Help-and-support
.. _Source code: https://github.com/asphalt-framework/asphalt-serialization
.. _Issue tracker: https://github.com/asphalt-framework/asphalt-serialization/issues
